# Generated by Django 3.1.6 on 2021-02-02 19:03

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0002_auto_20201101_1652'),
    ]

    operations = [
        migrations.AlterField(
            model_name='networkedge',
            name='child',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='parent_networkedges', to='tests.networknode'),
        ),
        migrations.AlterField(
            model_name='networkedge',
            name='parent',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='children_networkedges', to='tests.networknode'),
        ),
    ]
